@@ -12,7 +12,6 @@ import sys
 
 import requests
 
-# pyright: reportConstantRedefinition=false
 # pyright: reportMissingImports=false
 # pyright: reportUntypedBaseClass=false
 # pyright: reportUntypedFunctionDecorator=false
@@ -47,11 +46,16 @@ copyright = "2020, ComPWA"  # noqa: A001
 author = "Common Partial Wave Analysis"
 
 # https://docs.readthedocs.io/en/stable/builds.html
-BRANCH = os.environ.get("READTHEDOCS_VERSION", "stable")
-if BRANCH == "latest":
-    BRANCH = "main"
-if re.match(r"^\d+$", BRANCH):  # PR preview
-    BRANCH = "stable"
+def get_branch_name() -> str:
+    branch_name = os.environ.get("READTHEDOCS_VERSION", "stable")
+    if branch_name == "latest":
+        return "main"
+    if re.match(r"^\d+$", branch_name):  # PR preview
+        return "stable"
+    return branch_name
+
+
+BRANCH = get_branch_name()
 
 try:
     __VERSION = get_package_version(PACKAGE)
@@ -337,6 +341,7 @@ linkcheck_ignore = [
     "https://doi.org/10.1093/ptep/ptaa104",
     "https://home.fnal.gov/~kutschke/Angdist/angdist.ps",
     "https://hss-opus.ub.ruhr-uni-bochum.de",
+    "https://physique.cuso.ch",
     "https://suchung.web.cern.ch",
 ]
 
